﻿(function () {

    var document = window.document;
    var location = window.location;
    /*
    作用：返回选择的元素
    输入：selector:选择器
          sType: 返回类型,0,返回数组(如果有), 1,返回找到的第一个元素(如果有)
    输出：找到的元素
    */
    var qinson = function (selector, sType) {
        // 初始化qinson对象
        if (typeof sType === "undefined") {
            sType = 0;
        }
        return qinson.prototype.init(selector, sType);
    };
    qinson.prototype.init = function (selector, sType) {
        var el;
        if (!selector || typeof selector !== "string") return null;
        selector = qinson.trim(selector);
        //如果选择器，中间有空格,则进入复杂查询
        if (selector.indexOf(" ") > 0) {
            var arrStr = selector.split(" ");
            //这里需要判断一下全部是css选择器的情况
            var el;
            for (var i = 0; i < arrStr.length; i++) {
                el = qinson.find(arrStr[i], el);
                if (el == null) break;
            }
            return sType == 0 || el == null ? el : el[0];
        }
        
        //检查是不是复杂选择器,如果是，跳转
        //检查最左一位字符是啥，如果是#，则用 document.getElementById(), 如果是. 则用document.querySelectorAll()
        //如果没有，则用document.getElementsByName()
        if (selector[0] === "#") {
            selector = selector.replace("#", "");
            return document.getElementById(selector);
        } else if (selector[0] === ".") {
            el = document.querySelectorAll(selector);
        } else { //查找标签
            el = document.getElementsByTagName(selector);
        }
        if (el.length == 0) {
            el = null;
        } else if (sType === 1) {
            el = el[0];
        }
        return el;
    }

    /*
    作用：复杂查找
    输入:
    输出:返回找到的元素
    */
    qinson.find = function (selector, context) {
        if (typeof context === "undefined") context = document; //默认为当前文档
        if (!context) return null; //如果找到0个元素,直接返回
        var el;

        if (selector[0] === "#") {
            selector = selector.replace("#", "");
            return document.getElementById(selector);
        } else if (selector[0] === ".") {
            el = document.querySelectorAll(selector);
        } else { //查找标签
            el = document.getElementsByTagName(selector);
        }
        if (el.length == 0) {
            el = null;
        }
        return el;
    }

    /*
    作用：去除字符串两端的空格
    输入：x: 需要处理的字符串
    输出：字符串
    */
    qinson.trim = function (x) {
        return x.replace(/^\s+|\s+$/gm, '');
    }

    /*
    * 接收页面传参(未作中文兼容性处理)
    * 输入:x: 参数名称
    */
    qinson.request = function (strName) {
        var strHref = window.location.search;
        var intPos = strHref.indexOf("?");
        var strRight = strHref.substr(intPos + 1);
        var arrTmp = strRight.split("&");
        for (var i = 0; i < arrTmp.length; i++) {
            var arrTemp = arrTmp[i].split("=");
            if (arrTemp[0].toUpperCase() == strName.toUpperCase()) return arrTemp[1];
        }
        return "";
    }

    /*
    作用：得到cookie的值
    输入：name: cookie的名称
    输出：cookie的值
    */
    qinson.getCookie = function (name) {
        var start = document.cookie.indexOf(name + "=");
        var len = start + name.length + 1;
        if ((!start) && (name != document.cookie.substring(0, name.length))) return null;
        if (start == -1) return null;
        var end = document.cookie.indexOf(";", len);
        if (end == -1) end = document.cookie.length;
        return decodeURI(document.cookie.substring(len, end));
    } 

    /*
    作用：设置cookie的值
    输入：name: cookie的名称
    */
    qinson.setCookie =   function (name, value, expires, path, domain, secure) {
            expires = expires * 60 * 60 * 24 * 1000;
            var today = new Date();
            var expires_date = new Date(today.getTime() + (expires));
            var cookieString = name + "=" + decodeURIComponent(value)/** encodeURIComponent(value) 貌似也行**/ +
                ((expires) ? ";expires=" + expires_date.toGMTString() : "") +
                ((path) ? ";path=" + path : "") +
                ((domain) ? ";domain=" + domain : "") +
                ((secure) ? ";secure" : "");
            document.cookie = cookieString;
    }
    /*
 * 传递函数给whenReady()
 * 当文档解析完毕且为操作准备就绪时，函数作为document的方法调用
* 参考:https://www.cnblogs.com/leejersey/p/3409205.html
 */
    qinson.ready = function (fn) {               //这个函数返回whenReady()函数
        var funcs = [];             //当获得事件时，要运行的函数
        var ready = false;          //当触发事件处理程序时,切换为true

        //当文档就绪时,调用事件处理程序
        function handler(e) {          
            if (ready) return;       //确保事件处理程序只完整运行一次
            //如果发生onreadystatechange事件，但其状态不是complete的话,那么文档尚未准备好
            if (e.type === 'onreadystatechange' && document.readyState !== 'complete') {
                return;
            }
           
            //运行所有注册函数
            //注意每次都要计算funcs.length
            //以防这些函数的调用可能会导致注册更多的函数
            for (var i = 0; i < funcs.length; i++) {
                funcs[i].call(document);
            }
            //事件处理函数完整执行,切换ready状态, 并移除所有函数
            ready = true;
            funcs = null;
            fn();//执行事件
        }
        //为接收到的任何事件注册处理程序
        if (document.addEventListener) {
            document.addEventListener('DOMContentLoaded', handler, false);
            document.addEventListener('readystatechange', handler, false);            //IE9+
            window.addEventListener('load', handler, false);
        } else if (document.attachEvent) {
            document.attachEvent('onreadystatechange', handler);
            window.attachEvent('onload', handler);
        }
        //返回whenReady()函数
    }

    /*
    作用：隐藏传入的元素
    输入：el: document元素
    */
    qinson.hide = function (el) {
        if (el) {
            if (typeof el.length === "number") {
                for (i = 0; i < el.length; i++) {
                    console.log(el[i]);
                    el[i].style.display = "none";
                }
            } else {
                el.style.display = "none";
            }
        }
    }

     /*
    作用：显示传入的元素
    输入：el: document元素
    */
    qinson.show = function (el) {
        if (el) {
            if (typeof el.length === "number") {
                for (i = 0; i < el.length; i++) {
                    console.log(el[i]);
                    el[i].style.display = "";
                }
            } else {
                el.style.display = "";
            }
        }
    }

    /*
    * 作用：保留两位小数，主要应用于js浮点数不正确的时候
    * 功能：将浮点数四舍五入，取小数点后2位
    * 输入：x: 浮点数
    */
    qinson.toDecimal =  function (x) {
        var f = parseFloat(x);
        if (isNaN(f)) {
            return;
        }
        f = Math.round(x * 100) / 100;
        return f;
    } 


    qinson.ajax = {
        get: function (url, fn) {
            // XMLHttpRequest对象用于在后台与服务器交换数据   
            //var xhr = new XMLHttpRequest();
            var xhr = {};
            if (window.XDomainRequest) {
                xhr = new XDomainRequest();
                xhr.open("get", url);
            }

            else {
                xhr = new window.XMLHttpRequest();
                xhr.open('GET', url, true);
            }
           

            
            xhr.onreadystatechange = function () {
                // readyState == 4说明请求已完成
                if (xhr.readyState == 4 && xhr.status == 200 || xhr.status == 304) {
                    // 从服务器获得数据 
                    fn.call(this, xhr.responseText);
                }
            };
            xhr.send();
        },
        // datat应为'a=a1&b=b1'这种字符串格式，在jq里如果data为对象会自动将对象转成这种字符串格式
        post: function (url, data, fn) {
            var xhr = new XMLHttpRequest();
            xhr.open("POST", url, true);
            // 添加http头，发送信息至服务器时内容编码类型
            xhr.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
            xhr.onreadystatechange = function () {
                if (xhr.readyState == 4 && (xhr.status == 200 || xhr.status == 304)) {
                    fn.call(this, xhr.responseText);
                }
            };
            xhr.send(data);
        }
    }

    qinson.ajax2 = function (conf) {
        var xhr = null;
        if (window.XMLHttpRequest) {// 高版本浏览器
            xhr = new XMLHttpRequest();
        }
        else if (window.ActiveXObject) {//ie5,ie6
            xhr = new ActiveXObject("Microsoft.XMLHTTP");
        }
        return;

        var type = conf.type;//type参数,可选 
        var url = conf.url;//url参数，必填 
        var data = conf.data;//data参数可选，只有在post请求时需要 
        var dataType = conf.dataType;//datatype参数可选 
        var success = conf.success;//回调函数可选
        if (type == null) {//type参数可选，默认为get
            type = "get";
        }
        if (dataType == null) {//dataType参数可选，默认为text
            dataType = "text";
        }
        xhr.open(type, url, true);
        if (type == "GET" || type == "get") {
            xhr.send(null);
        } else if (type == "POST" || type == "post") {
            xhr.setRequestHeader("content-type", "application/x-www-form-urlencoded");
            xhr.send(data);
        }
        xhr.onreadystatechange = function () {
            if (xhr.readyState == 4 && xhr.status == 200) {
                if (dataType == "text" || dataType == "TEXT") {
                    if (success != null) {//普通文本
                        success(xhr.responseText);
                    }
                } else if (dataType == "xml" || dataType == "XML") {
                    if (success != null) {//接收xml文档
                        success(xhr.responseXML);
                    }
                } else if (dataType == "json" || dataType == "JSON") {
                    if (success != null) {//将json字符串转换为js对象
                        success(eval("(" + xhr.responseText + ")"));
                    }
                }
            }
        };
    }

    //将qinson设置为全局对象
    window.qinson = window.$q = qinson;
})
();